@@ -14,7 +14,8 @@ class SearchZone(ABC):
     def calculate_period_range(self, star_info: StarInfo):
         """
         Calculates the minimum and maximum periods for the given star_info
-        @param star_info: the star where the range should be calculated
-        @return: a tuple of minimum_period and maximum_period
+
+        :param star_info: the star where the range should be calculated
+        :return: a tuple of minimum_period and maximum_period
         """
         pass
